@@ -29,8 +29,7 @@
 
 #if HAVE_UNISTD_H
 # include <unistd.h>
-#endif
-#if HAVE_SYS_UNISTD_H
+#elif HAVE_SYS_UNISTD_H
 # include <sys/unistd.h>
 #endif
 #if HAVE_SYS_TYPES_H
@@ -44,8 +43,7 @@
 #endif
 #if HAVE_SIGNAL_H
 # include <signal.h>
-#endif
-#if HAVE_SYS_SIGNAL_H
+#elif HAVE_SYS_SIGNAL_H
 # include <sys/signal.h>
 #endif
 
@@ -350,7 +348,7 @@ main(int argc, char *argv[])
     char const *optstring = "o:78Rp:m:eb:Id:f:s:c:w:h:r:q:kil:t:ugvSn:PE:B:C:DVH";
 #if HAVE_GETOPT_LONG
     struct option long_options[] = {
-        {"outfile",          no_argument,        &long_opt, 'o'},
+        {"outfile",          required_argument,  &long_opt, 'o'},
         {"7bit-mode",        no_argument,        &long_opt, '7'},
         {"8bit-mode",        no_argument,        &long_opt, '8'},
         {"gri-limit",        no_argument,        &long_opt, 'R'},
