@@ -21,52 +21,24 @@
 
 #include "config.h"
 
-#if STDC_HEADERS
-# include <stdio.h>
-# include <stdlib.h>
-# include <stdarg.h>
-#endif  /* STDC_HEADERS */
-#if HAVE_STRING_H
-# include <string.h>
-#endif  /* HAVE_STRING_H */
+/* STDC_HEADERS */
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
 #if HAVE_UNISTD_H
 # include <unistd.h>
-#endif  /* HAVE_UNISTD_H */
-#if HAVE_SYS_UNISTD_H
+#elif HAVE_SYS_UNISTD_H
 # include <sys/unistd.h>
 #endif  /* HAVE_UNISTD_H */
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif  /* HAVE_SYS_TYPES_H */
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif  /* HAVE_SYS_SELECT_H */
-#if HAVE_TIME_H
-# include <time.h>
-#endif  /* HAVE_TIME_H */
-#if HAVE_SYS_TIME_H
-# include <sys/time.h>
-#endif  /* HAVE_SYS_TIME_H */
-#if HAVE_INTTYPES_H
-# include <inttypes.h>
-#endif  /* HAVE_INTTYPES_H */
 #if HAVE_ERRNO_H
 # include <errno.h>
-#endif  /* HAVE_ERRNO_H */
-#if HAVE_TERMIOS_H
-# include <termios.h>
-#endif  /* HAVE_TERMIOS_H */
-#if HAVE_SYS_IOCTL_H
-# include <sys/ioctl.h>
-#endif  /* HAVE_SYS_IOCTL_H */
-#if HAVE_IO_H
-# include <io.h>
-#endif  /* HAVE_IO_H */
+#endif /* HAVE_ERRNO_H */
 
 #include "decoder.h"
 
 
-/* original version of strdup(1) with allocator object */
+/* original version of strdup(3) with allocator object */
 static char *
 strdup_with_allocator(
     char const          /* in */ *s,          /* source buffer */
