@@ -21,11 +21,11 @@
 
 #include "config.h"
 
-#if STDC_HEADERS
-# include <string.h>
-# include <stdlib.h>
-# include <stdio.h>
-#endif  /* STDC_HEADERS */
+/* STDC_HEADERS */
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
+
 #if HAVE_MATH_H
 # include <math.h>
 #endif  /* HAVE_MATH_H */
@@ -553,6 +553,11 @@ sixel_frame_resize(
         goto end;
     }
 
+    if (width == frame->width && height == frame->height) {
+        /* nothing to do */
+        goto out;
+    }
+
     status = sixel_frame_convert_to_rgb888(frame);
     if (SIXEL_FAILED(status)) {
         goto end;
@@ -585,6 +590,7 @@ sixel_frame_resize(
     frame->width = width;
     frame->height = height;
 
+out:
     status = SIXEL_OK;
 
 end:
