@@ -46,10 +46,10 @@
 
 #include "config.h"
 
-#if STDC_HEADERS
-# include <stdlib.h>
-# include <stdio.h>
-#endif  /* STDC_HEADERS */
+/* STDC_HEADERS */
+#include <stdlib.h>
+#include <stdio.h>
+
 #if HAVE_STRING_H
 # include <string.h>
 #endif  /* HAVE_STRING_H */
@@ -700,23 +700,17 @@ computeHistogram(unsigned char const    /* in */  *data,
     switch (qualityMode) {
     case SIXEL_QUALITY_LOW:
         max_sample = 18383;
-        step = length / depth / max_sample * depth;
         break;
     case SIXEL_QUALITY_HIGH:
-        max_sample = 18383;
-        step = length / depth / max_sample * depth;
+        max_sample = 1118383;
         break;
     case SIXEL_QUALITY_FULL:
     default:
         max_sample = 4003079;
-        step = length / depth / max_sample * depth;
         break;
     }
 
-    if (length < max_sample * depth) {
-        step = 6 * depth;
-    }
-
+    step = length / depth / max_sample * depth;
     if (step <= 0) {
         step = depth;
     }
@@ -1289,6 +1283,13 @@ sixel_quant_apply_palette(
         goto end;
     }
 
+    /* NOTE: diffuse_jajuni, diffuse_stucki, and diffuse_burkes reference at
+     * minimum the position pos + width * 1 - 2, so width must be at least 2
+     * to avoid underflow.
+     * On the other hand, diffuse_fs and diffuse_atkinson
+     * reference pos + width * 1 - 1, but since these functions are only called
+     * when width >= 1, they do not cause underflow.
+     */
     if (depth != 3) {
         f_diffuse = diffuse_none;
     } else {
@@ -1303,13 +1304,16 @@ sixel_quant_apply_palette(
             f_diffuse = diffuse_fs;
             break;
         case SIXEL_DIFFUSE_JAJUNI:
-            f_diffuse = diffuse_jajuni;
+            /* fallback to diffuse_none if width < 2 */
+            f_diffuse = width >= 2 ? diffuse_jajuni: diffuse_none;
             break;
         case SIXEL_DIFFUSE_STUCKI:
-            f_diffuse = diffuse_stucki;
+            /* fallback to diffuse_none if width < 2 */
+            f_diffuse = width >= 2 ? diffuse_stucki: diffuse_none;
             break;
         case SIXEL_DIFFUSE_BURKES:
-            f_diffuse = diffuse_burkes;
+            /* fallback to diffuse_none if width < 2 */
+            f_diffuse = width >= 2 ? diffuse_burkes: diffuse_none;
             break;
         case SIXEL_DIFFUSE_A_DITHER:
             f_diffuse = diffuse_none;
