@@ -19,10 +19,10 @@
  */
 #include "config.h"
 
-#if STDC_HEADERS
-# include <stdio.h>
-# include <stdlib.h>
-#endif  /* HAVE_STDLIB_H */
+/* STDC_HEADERS */
+#include <stdio.h>
+#include <stdlib.h>
+
 #if HAVE_STRING_H
 # include <string.h>
 #endif  /* HAVE_STRING_H */
@@ -279,20 +279,16 @@ sixel_put_node(
     }
 
     for (; *x < np->sx; ++*x) {
-        if (*x != keycolor) {
-            status = sixel_put_pixel(output, 0);
-            if (SIXEL_FAILED(status)) {
-                goto end;
-            }
+        status = sixel_put_pixel(output, 0);
+        if (SIXEL_FAILED(status)) {
+            goto end;
         }
     }
 
     for (; *x < np->mx; ++*x) {
-        if (*x != keycolor) {
-            status = sixel_put_pixel(output, np->map[*x]);
-            if (SIXEL_FAILED(status)) {
-                goto end;
-            }
+        status = sixel_put_pixel(output, np->map[*x]);
+        if (SIXEL_FAILED(status)) {
+            goto end;
         }
     }
 
